/**
 * Copyright (c) 2017-2018 INCHRON GmbH
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     INCHRON GmbH - Meta Model design and implementation
 */
package com.inchron.realtime.root.model.stimulation.util;

import com.inchron.realtime.root.Referrable;

import com.inchron.realtime.root.model.ClockUser;
import com.inchron.realtime.root.model.ModelObject;

import com.inchron.realtime.root.model.stimulation.*;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EPackage;

import org.eclipse.emf.ecore.util.Switch;

/**
 * <!-- begin-user-doc -->
 * The <b>Switch</b> for the model's inheritance hierarchy.
 * It supports the call {@link #doSwitch(EObject) doSwitch(object)}
 * to invoke the <code>caseXXX</code> method for each class of the model,
 * starting with the actual class of the object
 * and proceeding up the inheritance hierarchy
 * until a non-null result is returned,
 * which is the result of the switch.
 * <!-- end-user-doc -->
 * @see com.inchron.realtime.root.model.stimulation.StimulationPackage
 * @generated
 */
public class StimulationSwitch<T> extends Switch<T> {
	/**
	 * The cached model package
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected static StimulationPackage modelPackage;

	/**
	 * Creates an instance of the switch.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public StimulationSwitch() {
		if (modelPackage == null) {
			modelPackage = StimulationPackage.eINSTANCE;
		}
	}

	/**
	 * Checks whether this is a switch for the given package.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param ePackage the package in question.
	 * @return whether this is a switch for the given package.
	 * @generated
	 */
	@Override
	protected boolean isSwitchFor(EPackage ePackage) {
		return ePackage == modelPackage;
	}

	/**
	 * Calls <code>caseXXX</code> for each class of the model until one returns a non null result; it yields that result.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the first non-null result returned by a <code>caseXXX</code> call.
	 * @generated
	 */
	@Override
	protected T doSwitch(int classifierID, EObject theEObject) {
		switch (classifierID) {
			case StimulationPackage.BURST_PATTERN: {
				BurstPattern burstPattern = (BurstPattern)theEObject;
				T result = caseBurstPattern(burstPattern);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.BURST_PATTERN_GENERATOR: {
				BurstPatternGenerator burstPatternGenerator = (BurstPatternGenerator)theEObject;
				T result = caseBurstPatternGenerator(burstPatternGenerator);
				if (result == null) result = caseStimuliGenerator(burstPatternGenerator);
				if (result == null) result = caseModelObject(burstPatternGenerator);
				if (result == null) result = caseClockUser(burstPatternGenerator);
				if (result == null) result = caseReferrable(burstPatternGenerator);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.CSV_BASED_GENERATOR: {
				CSVBasedGenerator csvBasedGenerator = (CSVBasedGenerator)theEObject;
				T result = caseCSVBasedGenerator(csvBasedGenerator);
				if (result == null) result = caseStimuliGenerator(csvBasedGenerator);
				if (result == null) result = caseModelObject(csvBasedGenerator);
				if (result == null) result = caseClockUser(csvBasedGenerator);
				if (result == null) result = caseReferrable(csvBasedGenerator);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.COMPOSITE_SCENARIO: {
				CompositeScenario compositeScenario = (CompositeScenario)theEObject;
				T result = caseCompositeScenario(compositeScenario);
				if (result == null) result = caseStimulationScenario(compositeScenario);
				if (result == null) result = caseModelObject(compositeScenario);
				if (result == null) result = caseReferrable(compositeScenario);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.DISTURBANCE_FILTER: {
				DisturbanceFilter disturbanceFilter = (DisturbanceFilter)theEObject;
				T result = caseDisturbanceFilter(disturbanceFilter);
				if (result == null) result = caseStimulationFilter(disturbanceFilter);
				if (result == null) result = caseModelObject(disturbanceFilter);
				if (result == null) result = caseReferrable(disturbanceFilter);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.DRIFT_FILTER: {
				DriftFilter driftFilter = (DriftFilter)theEObject;
				T result = caseDriftFilter(driftFilter);
				if (result == null) result = caseStimulationFilter(driftFilter);
				if (result == null) result = caseModelObject(driftFilter);
				if (result == null) result = caseReferrable(driftFilter);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.ELIMINATION_FILTER: {
				EliminationFilter eliminationFilter = (EliminationFilter)theEObject;
				T result = caseEliminationFilter(eliminationFilter);
				if (result == null) result = caseStimulationFilter(eliminationFilter);
				if (result == null) result = caseModelObject(eliminationFilter);
				if (result == null) result = caseReferrable(eliminationFilter);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.INDUCED_GENERATOR: {
				InducedGenerator inducedGenerator = (InducedGenerator)theEObject;
				T result = caseInducedGenerator(inducedGenerator);
				if (result == null) result = caseStimuliGenerator(inducedGenerator);
				if (result == null) result = caseModelObject(inducedGenerator);
				if (result == null) result = caseClockUser(inducedGenerator);
				if (result == null) result = caseReferrable(inducedGenerator);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.INDUCED_LIST_BASED_GENERATOR: {
				InducedListBasedGenerator inducedListBasedGenerator = (InducedListBasedGenerator)theEObject;
				T result = caseInducedListBasedGenerator(inducedListBasedGenerator);
				if (result == null) result = caseListBasedGenerator(inducedListBasedGenerator);
				if (result == null) result = caseStimuliGenerator(inducedListBasedGenerator);
				if (result == null) result = caseModelObject(inducedListBasedGenerator);
				if (result == null) result = caseClockUser(inducedListBasedGenerator);
				if (result == null) result = caseReferrable(inducedListBasedGenerator);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.LIST_BASED_GENERATOR: {
				ListBasedGenerator listBasedGenerator = (ListBasedGenerator)theEObject;
				T result = caseListBasedGenerator(listBasedGenerator);
				if (result == null) result = caseStimuliGenerator(listBasedGenerator);
				if (result == null) result = caseModelObject(listBasedGenerator);
				if (result == null) result = caseClockUser(listBasedGenerator);
				if (result == null) result = caseReferrable(listBasedGenerator);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.RANDOM_STIMULI_GENERATOR: {
				RandomStimuliGenerator randomStimuliGenerator = (RandomStimuliGenerator)theEObject;
				T result = caseRandomStimuliGenerator(randomStimuliGenerator);
				if (result == null) result = caseStimuliGenerator(randomStimuliGenerator);
				if (result == null) result = caseModelObject(randomStimuliGenerator);
				if (result == null) result = caseClockUser(randomStimuliGenerator);
				if (result == null) result = caseReferrable(randomStimuliGenerator);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.STIMULATION_FILTER: {
				StimulationFilter stimulationFilter = (StimulationFilter)theEObject;
				T result = caseStimulationFilter(stimulationFilter);
				if (result == null) result = caseModelObject(stimulationFilter);
				if (result == null) result = caseReferrable(stimulationFilter);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.STIMULATION_SCENARIO: {
				StimulationScenario stimulationScenario = (StimulationScenario)theEObject;
				T result = caseStimulationScenario(stimulationScenario);
				if (result == null) result = caseModelObject(stimulationScenario);
				if (result == null) result = caseReferrable(stimulationScenario);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case StimulationPackage.STIMULI_GENERATOR: {
				StimuliGenerator stimuliGenerator = (StimuliGenerator)theEObject;
				T result = caseStimuliGenerator(stimuliGenerator);
				if (result == null) result = caseModelObject(stimuliGenerator);
				if (result == null) result = caseClockUser(stimuliGenerator);
				if (result == null) result = caseReferrable(stimuliGenerator);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			default: return defaultCase(theEObject);
		}
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Burst Pattern</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Burst Pattern</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseBurstPattern(BurstPattern object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Burst Pattern Generator</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Burst Pattern Generator</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseBurstPatternGenerator(BurstPatternGenerator object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>CSV Based Generator</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>CSV Based Generator</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseCSVBasedGenerator(CSVBasedGenerator object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Composite Scenario</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Composite Scenario</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseCompositeScenario(CompositeScenario object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Disturbance Filter</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Disturbance Filter</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDisturbanceFilter(DisturbanceFilter object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Drift Filter</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Drift Filter</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDriftFilter(DriftFilter object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Elimination Filter</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Elimination Filter</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseEliminationFilter(EliminationFilter object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Induced Generator</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Induced Generator</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseInducedGenerator(InducedGenerator object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Induced List Based Generator</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Induced List Based Generator</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseInducedListBasedGenerator(InducedListBasedGenerator object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>List Based Generator</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>List Based Generator</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseListBasedGenerator(ListBasedGenerator object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Random Stimuli Generator</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Random Stimuli Generator</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseRandomStimuliGenerator(RandomStimuliGenerator object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Filter</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Filter</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseStimulationFilter(StimulationFilter object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Scenario</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Scenario</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseStimulationScenario(StimulationScenario object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Stimuli Generator</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Stimuli Generator</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseStimuliGenerator(StimuliGenerator object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Referrable</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Referrable</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseReferrable(Referrable object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Object</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Object</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModelObject(ModelObject object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Clock User</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Clock User</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseClockUser(ClockUser object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>EObject</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch, but this is the last case anyway.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>EObject</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject)
	 * @generated
	 */
	@Override
	public T defaultCase(EObject object) {
		return null;
	}

} //StimulationSwitch
