/**
 ********************************************************************************
 * Copyright (c) 2017-2020 Robert Bosch GmbH and others.
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Robert Bosch GmbH - initial API and implementation
 ********************************************************************************
 */
package org.eclipse.app4mc.sca2amalthea.utils.constants;

import org.eclipse.app4mc.sca2amalthea.utils.Activator;
import org.eclipse.jface.preference.IPreferenceStore;

/**
 * Constants for all the SCA2Amalthea operations
 */
public final class SCA2AmaltheaConstants {

  /**
   * Added private constructor to hide the implicit public one
   */
  private SCA2AmaltheaConstants() {
    // empty constructor
  }

  /**
  *
  */
  public static final String TASK_INFO = "taskInfo";
  /**
  *
  */
  public static final String OUTPUT_PATH = "outputPath";
  /**
  *
  */
  public static final String AST_PATH = "astPath";
  /**
  *
  */
  public static final String LOCK_INFO = "lockInfo";
  /**
  *
  */
  public static final String BLOG = "blog";
  /**
  *
  */
  public static final String HDIR_LIST = "hdirList";


  /**
   *
   */
  public static final String DEBUG_MODE = "debugMode";

  /**
   * Preference name for the "Disable struct member" option
   */
  public static final String ENABLE_STRUCT_MEMBER = "enableStructMember";

  /**
   * Preference name for "Component model based on fc bc"
   */
  public static final String COMPONENT_MODEL_FC_BC = "componentModelFcBc";


  /**
   * Preference name for "Configure optional fields" option
   */
  public static final String ENABLE_OPTIONAL_FIELDS = "enableOptionalFields";

  /**
   *
   */
  public static final String OPT_FILE_PATH = "optFile";

  /**
   *
   */
  public static final String INI_TASK_CYCLE = "ONCE";

  /**
   * This method returns the preference store of the sca2Amalthea component.
   *
   * @return IPreferenceStore preference store
   */
  public static IPreferenceStore getPreferenceStore() {
    return Activator.getDefault().getPreferenceStore();
  }

}
